@@ -27,6 +27,10 @@ class PyDMEmbeddedDisplay(QFrame, PyDMPrimitiveWidget):
     def __init__(self, parent=None):
         QFrame.__init__(self, parent)
         PyDMPrimitiveWidget.__init__(self)
+        if 'Filename' not in PyDMEmbeddedDisplay.RULE_PROPERTIES:
+            PyDMEmbeddedDisplay.RULE_PROPERTIES = PyDMPrimitiveWidget.RULE_PROPERTIES.copy()
+            PyDMEmbeddedDisplay.RULE_PROPERTIES.update(
+                {'Filename': ['filename', str]})
         self.app = QApplication.instance()
         self._filename = None
         self._macros = None
