@@ -4,7 +4,7 @@ try:
 except ImportError:
     from cgi import escape  # Can't only use this since it was removed in Python 3.8 and up
 from collections import Counter
-from pyqtgraph import GraphicsWidget, PlotItem, ViewBox
+from pyqtgraph import PlotItem, ViewBox
 from .multi_axis_viewbox import MultiAxisViewBox
 from .multi_axis_viewbox_menu import MultiAxisViewBoxMenu
 
@@ -77,10 +77,7 @@ class MultiAxisPlot(PlotItem):
         view.setYRange(minRange, maxRange)
         view.enableAutoRange(axis=ViewBox.XAxis, enable=enableAutoRangeX)
         view.enableAutoRange(axis=ViewBox.YAxis, enable=enableAutoRangeY)
-        if setXLink:
-            view.setXLink(self)  # Link this view to the shared x-axis of this plot item
-        else:
-            self.axes['bottom']['item'].linkToView(view)  # Ensure the x axis will update when the view does
+        self.axes['bottom']['item'].linkToView(view)  # Ensure the x axis will update when the view does
 
         view.setMouseMode(self.vb.state['mouseMode'])  # Ensure that mouse behavior is consistent between stacked views
         axis.linkToView(view)
@@ -93,7 +90,6 @@ class MultiAxisPlot(PlotItem):
 
         # Rebuilding the layout of the plot item will put the new axis in the correct place
         self.rebuildLayout()
-        self.updateStackedViews()
 
     def addStackedView(self, view):
         """
@@ -188,7 +184,6 @@ class MultiAxisPlot(PlotItem):
         oldAxis.unlinkFromView()
         del self.axes[axisName]
 
-
     def unlinkDataFromAxis(self, axisName):
         """
         Lets the plot know that this axis is now associated with one less curve. If there are no
@@ -243,6 +238,11 @@ class MultiAxisPlot(PlotItem):
             view.setYRange(minY, maxY, padding=padding)
         super(MultiAxisPlot, self).setYRange(minY, maxY, padding=padding)
 
+    def disableXAutoRange(self):
+        """ Disable x-axis autorange for all views in the plot. """
+        for view in self.stackedViews:
+            view.enableAutoRange(x=False)
+
     def clearAxes(self):
         """
         Cleans up all axis related data from this plot.
