@@ -4,6 +4,7 @@ from qtpy import QtWidgets, QtCore
 from ..widgets.base import PyDMPrimitiveWidget
 
 from ..widgets.rules_editor import RulesEditor
+from ..widgets.archiver_time_plot_editor import ArchiverTimePlotCurveEditorDialog
 from ..widgets.waveformplot_curve_editor import WaveformPlotCurveEditorDialog
 from ..widgets.timeplot_curve_editor import TimePlotCurveEditorDialog
 from ..widgets.scatterplot_curve_editor import ScatterPlotCurveEditorDialog
@@ -117,6 +118,11 @@ class WaveformCurveEditorExtension(BasePlotExtension):
         super(WaveformCurveEditorExtension, self).__init__(widget, WaveformPlotCurveEditorDialog)
 
 
+class ArchiveTimeCurveEditorExtension(BasePlotExtension):
+    def __init__(self, widget):
+        super(ArchiveTimeCurveEditorExtension, self).__init__(widget, ArchiverTimePlotCurveEditorDialog)
+
+
 class TimeCurveEditorExtension(BasePlotExtension):
     def __init__(self, widget):
         super(TimeCurveEditorExtension, self).__init__(widget, TimePlotCurveEditorDialog)
