@@ -5,7 +5,6 @@ from pyqtgraph import ViewBox, AxisItem
 import numpy as np
 from qtpy.QtGui import QColor
 from qtpy.QtCore import Signal, Slot, Property, QTimer
-from qtpy.QtWidgets import QAction
 from .baseplot import BasePlot, BasePlotCurveItem
 from .channel import PyDMChannel
 from .. utilities import remove_protocol
@@ -162,7 +161,7 @@ class TimePlotCurveItem(BasePlotCurveItem):
         For Asynchronous, write the new value into a temporary (buffered)
         variable, which will be written to the data buffer when asyncUpdate
         is called.
-        
+
         This method is usually called by a PyDMChannel when it updates.  You
         can call it yourself to inject data into the curve.
 
@@ -204,7 +203,7 @@ class TimePlotCurveItem(BasePlotCurveItem):
 
     def update_min_max_y_values(self, new_value):
         """
-        Updte the min and max y-value as a new value is available. This is
+        Update the min and max y-value as a new value is available. This is
         useful for auto-scaling to a specific curve.
 
         Parameters
@@ -392,7 +391,7 @@ class PyDMTimePlot(BasePlot):
 
     def addYChannel(self, y_channel=None, name=None, color=None,
                     lineStyle=None, lineWidth=None, symbol=None,
-                    symbolSize=None, yAxisName=None):
+                    symbolSize=None, yAxisName=None, useArchiveData=False):
         """
         Adds a new curve to the current plot
 
@@ -432,8 +431,8 @@ class PyDMTimePlot(BasePlot):
             plot_opts['lineWidth'] = lineWidth
 
         # Add curve
-        new_curve = TimePlotCurveItem(y_channel, plot_by_timestamps=self._plot_by_timestamps, name=name, color=color,
-                                      yAxisName=yAxisName, **plot_opts)
+        new_curve = self.createCurveItem(y_channel, self._plot_by_timestamps, name, color=color,
+                                         yAxisName=yAxisName, useArchiveData=useArchiveData, **plot_opts)
         new_curve.setUpdatesAsynchronously(self.updatesAsynchronously)
         new_curve.setBufferSize(self._bufferSize)
 
@@ -445,6 +444,10 @@ class PyDMTimePlot(BasePlot):
 
         return new_curve
 
+    def createCurveItem(self, y_channel, plot_by_timestamps, name, color, yAxisName, useArchiveData, **plot_opts):
+        return TimePlotCurveItem(y_channel, plot_by_timestamps=plot_by_timestamps,
+                                 name=name, color=color, yAxisName=yAxisName, **plot_opts)
+
     def removeYChannel(self, curve):
         """
         Remove a curve from the graph. This also stops update the timer
